netapp_ontap.models.nvme_subsystem_hosts API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_subsystem_hosts`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeSubsystemHostsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemHosts object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `nqn GET POST`

    The NVMe qualified name (NQN) used to identify the NVMe storage target.

    Example: nqn.1992-01.example.com:string